summaryrefslogtreecommitdiff
path: root/include/linux/ptrace.h
diff options
context:
space:
mode:
authorRoland McGrath <roland@redhat.com>2008-01-30 13:30:53 +0100
committerIngo Molnar <mingo@elte.hu>2008-01-30 13:30:53 +0100
commitdc802c2d2e66e2d1544e023bfd4be6cdee48d57b (patch)
treef3b2f58da24d67e70fee9c9e0ef2146c12ea13c2 /include/linux/ptrace.h
parentd9771e8c50020bb1b4ca9eca9c188874ff126aa4 (diff)
ptrace: arch_has_block_step
This defines the new macro arch_has_block_step() in linux/ptrace.h, a default for when asm/ptrace.h does not define it. This is the analog of arch_has_single_step() for step-until-branch on machines that have it. It declares the new user_enable_block_step function, which goes with the existing user_enable_single_step and user_disable_single_step. This is not used yet, but paves the way to harmonize on this interface for the arch-specific calls on all machines. Signed-off-by: Roland McGrath <roland@redhat.com> Signed-off-by: Ingo Molnar <mingo@elte.hu> Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Diffstat (limited to 'include/linux/ptrace.h')
-rw-r--r--include/linux/ptrace.h37
1 files changed, 33 insertions, 4 deletions
diff --git a/include/linux/ptrace.h b/include/linux/ptrace.h
index 8f06c6fb22a5..1febc541dda5 100644
--- a/include/linux/ptrace.h
+++ b/include/linux/ptrace.h
@@ -155,7 +155,8 @@ int generic_ptrace_pokedata(struct task_struct *tsk, long addr, long data);
*
* This can only be called when arch_has_single_step() has returned nonzero.
* Set @task so that when it returns to user mode, it will trap after the
- * next single instruction executes.
+ * next single instruction executes. If arch_has_block_step() is defined,
+ * this must clear the effects of user_enable_block_step() too.
*/
static inline void user_enable_single_step(struct task_struct *task)
{
@@ -166,15 +167,43 @@ static inline void user_enable_single_step(struct task_struct *task)
* user_disable_single_step - cancel user-mode single-step
* @task: either current or a task stopped in %TASK_TRACED
*
* Clear @task of the effects of user_enable_single_step(). This can
* be called whether or not user_enable_single_step() was ever called
* on @task, and even if arch_has_single_step() returned zero.
*/
static inline void user_disable_single_step(struct task_struct *task)
{
}
#endif /* arch_has_single_step */
+#ifndef arch_has_block_step
+/**
+ * arch_has_block_step - does this CPU support user-mode block-step?
+ *
+ * If this is defined, then there must be a function declaration or inline
+ * for user_enable_block_step(), and arch_has_single_step() must be defined
+ * too. arch_has_block_step() should evaluate to nonzero iff the machine
+ * supports step-until-branch for user mode. It can be a constant or it
+ * can test a CPU feature bit.
+ */
+#define arch_has_single_step() (0)
+
+/**
+ * user_enable_block_step - step until branch in user-mode task
+ * @task: either current or a task stopped in %TASK_TRACED
+ *
+ * This can only be called when arch_has_block_step() has returned nonzero,
+ * and will never be called when single-instruction stepping is being used.
+ * Set @task so that when it returns to user mode, it will trap after the
+ * next branch or trap taken.
+ */
+static inline void user_enable_block_step(struct task_struct *task)
+{
+ BUG(); /* This can never be called. */
+}
+#endif /* arch_has_block_step */
+
#endif
#endif
@@ -166,15 +167,43 @@ static inline void user_enable_single_step(struct task_struct *task)
* @task: either current or a task stopped in %TASK_TRACED
*
- * Clear @task of the effects of user_enable_single_step(). This can
- * be called whether or not user_enable_single_step() was ever called
- * on @task, and even if arch_has_single_step() returned zero.
+ * Clear @task of the effects of user_enable_single_step() and
+ * user_enable_block_step(). This can be called whether or not either
+ * of those was ever called on @task, and even if arch_has_single_step()
+ * returned zero.
*/
static inline void user_disable_single_step(struct task_struct *task)